@@ -4,27 +4,19 @@ from __future__ import annotations
 
 import re
 from functools import partial
-from typing import (
-    TYPE_CHECKING,
-    Collection,
-    Iterable,
-    Iterator,
-    Protocol,
-    Sequence,
-    TypeVar,
-    overload,
-)
+from typing import TYPE_CHECKING, Protocol, TypeVar, overload
 
 from narwhals._compliant.expr import CompliantExpr
-from narwhals._typing_compat import Protocol38
-from narwhals.utils import (
+from narwhals._utils import (
     _parse_time_unit_and_time_zone,
     dtype_matches_time_unit_and_time_zone,
     get_column_names,
     is_compliant_dataframe,
+    zip_strict,
 )
 
 if TYPE_CHECKING:
+    from collections.abc import Collection, Iterable, Iterator, Sequence
     from datetime import timezone
 
     from typing_extensions import Self, TypeAlias, TypeIs
@@ -39,11 +31,10 @@ if TYPE_CHECKING:
         CompliantSeriesOrNativeExprAny,
         EvalNames,
         EvalSeries,
-        ScalarKwargs,
     )
+    from narwhals._utils import Implementation, Version, _LimitedContext
     from narwhals.dtypes import DType
     from narwhals.typing import TimeUnit
-    from narwhals.utils import Implementation, Version, _FullContext
 
 __all__ = [
     "CompliantSelector",
@@ -65,31 +56,26 @@ SelectorOrExpr: TypeAlias = (
 
 
 class CompliantSelectorNamespace(Protocol[FrameT, SeriesOrExprT]):
+    # NOTE: `narwhals`
     _implementation: Implementation
-    _backend_version: tuple[int, ...]
     _version: Version
 
-    @classmethod
-    def from_namespace(cls, context: _FullContext, /) -> Self:
-        obj = cls.__new__(cls)
-        obj._implementation = context._implementation
-        obj._backend_version = context._backend_version
-        obj._version = context._version
-        return obj
-
     @property
     def _selector(self) -> type[CompliantSelector[FrameT, SeriesOrExprT]]: ...
+    @classmethod
+    def from_namespace(cls, context: _LimitedContext, /) -> Self:
+        obj = cls.__new__(cls)
+        obj._implementation = context._implementation
+        obj._version = context._version
+        return obj
 
     def _iter_columns(self, df: FrameT, /) -> Iterator[SeriesOrExprT]: ...
-
     def _iter_schema(self, df: FrameT, /) -> Iterator[tuple[str, DType]]: ...
-
     def _iter_columns_dtypes(
         self, df: FrameT, /
     ) -> Iterator[tuple[SeriesOrExprT, DType]]: ...
-
     def _iter_columns_names(self, df: FrameT, /) -> Iterator[tuple[SeriesOrExprT, str]]:
-        yield from zip(self._iter_columns(df), df.columns)
+        yield from zip_strict(self._iter_columns(df), df.columns)
 
     def _is_dtype(
         self: CompliantSelectorNamespace[FrameT, SeriesOrExprT], dtype: type[DType], /
@@ -104,6 +90,7 @@ class CompliantSelectorNamespace(Protocol[FrameT, SeriesOrExprT]):
 
         return self._selector.from_callables(series, names, context=self)
 
+    # NOTE: `polars`
     def by_dtype(
         self, dtypes: Collection[DType | type[DType]]
     ) -> CompliantSelector[FrameT, SeriesOrExprT]:
@@ -204,19 +191,16 @@ class LazySelectorNamespace(
         yield from df._iter_columns()
 
     def _iter_columns_dtypes(self, df: LazyFrameT, /) -> Iterator[tuple[ExprT, DType]]:
-        yield from zip(self._iter_columns(df), df.schema.values())
+        yield from zip_strict(self._iter_columns(df), df.schema.values())
 
 
 class CompliantSelector(
-    CompliantExpr[FrameT, SeriesOrExprT], Protocol38[FrameT, SeriesOrExprT]
+    CompliantExpr[FrameT, SeriesOrExprT], Protocol[FrameT, SeriesOrExprT]
 ):
     _call: EvalSeries[FrameT, SeriesOrExprT]
     _function_name: str
-    _depth: int
     _implementation: Implementation
-    _backend_version: tuple[int, ...]
     _version: Version
-    _scalar_kwargs: ScalarKwargs
 
     @classmethod
     def from_callables(
@@ -224,18 +208,14 @@ class CompliantSelector(
         call: EvalSeries[FrameT, SeriesOrExprT],
         evaluate_output_names: EvalNames[FrameT],
         *,
-        context: _FullContext,
+        context: _LimitedContext,
     ) -> Self:
         obj = cls.__new__(cls)
         obj._call = call
-        obj._depth = 0
-        obj._function_name = "selector"
         obj._evaluate_output_names = evaluate_output_names
         obj._alias_output_names = None
         obj._implementation = context._implementation
-        obj._backend_version = context._backend_version
         obj._version = context._version
-        obj._scalar_kwargs = {}
         return obj
 
     @property
@@ -263,7 +243,9 @@ class CompliantSelector(
             def series(df: FrameT) -> Sequence[SeriesOrExprT]:
                 lhs_names, rhs_names = _eval_lhs_rhs(df, self, other)
                 return [
-                    x for x, name in zip(self(df), lhs_names) if name not in rhs_names
+                    x
+                    for x, name in zip_strict(self(df), lhs_names)
+                    if name not in rhs_names
                 ]
 
             def names(df: FrameT) -> Sequence[str]:
@@ -287,7 +269,11 @@ class CompliantSelector(
             def series(df: FrameT) -> Sequence[SeriesOrExprT]:
                 lhs_names, rhs_names = _eval_lhs_rhs(df, self, other)
                 return [
-                    *(x for x, name in zip(self(df), lhs_names) if name not in rhs_names),
+                    *(
+                        x
+                        for x, name in zip_strict(self(df), lhs_names)
+                        if name not in rhs_names
+                    ),
                     *other(df),
                 ]
 
@@ -311,7 +297,9 @@ class CompliantSelector(
 
             def series(df: FrameT) -> Sequence[SeriesOrExprT]:
                 lhs_names, rhs_names = _eval_lhs_rhs(df, self, other)
-                return [x for x, name in zip(self(df), lhs_names) if name in rhs_names]
+                return [
+                    x for x, name in zip_strict(self(df), lhs_names) if name in rhs_names
+                ]
 
             def names(df: FrameT) -> Sequence[str]:
                 lhs_names, rhs_names = _eval_lhs_rhs(df, self, other)
