@@ -17,7 +17,7 @@ from narwhals._expression_parsing import (
     combine_evaluate_output_names,
 )
 from narwhals._sql.typing import SQLLazyFrameT
-from narwhals._utils import Implementation, Version, not_implemented
+from narwhals._utils import Implementation, Version, extend_bool, not_implemented
 
 if TYPE_CHECKING:
     from collections.abc import Iterable, Sequence
@@ -228,6 +228,7 @@ class SQLExpr(LazyExpr[SQLLazyFrameT, NativeExprT], Protocol[SQLLazyFrameT, Nati
         def func(
             df: SQLLazyFrameT, inputs: WindowInputs[NativeExprT]
         ) -> Sequence[NativeExprT]:
+            flags = extend_bool(reverse, len(inputs.order_by))
             return [
                 self._when(
                     ~self._function("isnull", expr),  # type: ignore[operator]
@@ -235,8 +236,8 @@ class SQLExpr(LazyExpr[SQLLazyFrameT, NativeExprT], Protocol[SQLLazyFrameT, Nati
                         self._function(func_name, expr),
                         inputs.partition_by,
                         inputs.order_by,
-                        descending=[reverse] * len(inputs.order_by),
-                        nulls_last=[reverse] * len(inputs.order_by),
+                        descending=flags,
+                        nulls_last=flags,
                         rows_end=0,
                     ),
                 )
@@ -568,6 +569,12 @@ class SQLExpr(LazyExpr[SQLLazyFrameT, NativeExprT], Protocol[SQLLazyFrameT, Nati
             lambda expr: self._function("round", expr, self._lit(decimals))
         )
 
+    def floor(self) -> Self:
+        return self._with_elementwise(lambda expr: self._function("floor", expr))
+
+    def ceil(self) -> Self:
+        return self._with_elementwise(lambda expr: self._function("ceil", expr))
+
     def sqrt(self) -> Self:
         def _sqrt(expr: NativeExprT) -> NativeExprT:
             return self._when(
@@ -608,13 +615,14 @@ class SQLExpr(LazyExpr[SQLLazyFrameT, NativeExprT], Protocol[SQLLazyFrameT, Nati
         def func(
             df: SQLLazyFrameT, inputs: WindowInputs[NativeExprT]
         ) -> Sequence[NativeExprT]:
+            flags = extend_bool(reverse, len(inputs.order_by))
             return [
                 self._window_expression(
                     self._function("count", expr),
                     inputs.partition_by,
                     inputs.order_by,
-                    descending=[reverse] * len(inputs.order_by),
-                    nulls_last=[reverse] * len(inputs.order_by),
+                    descending=flags,
+                    nulls_last=flags,
                     rows_end=0,
                 )
                 for expr in self(df)
@@ -704,13 +712,14 @@ class SQLExpr(LazyExpr[SQLLazyFrameT, NativeExprT], Protocol[SQLLazyFrameT, Nati
         def func(
             df: SQLLazyFrameT, inputs: WindowInputs[NativeExprT]
         ) -> Sequence[NativeExprT]:
+            flags = extend_bool(True, len(inputs.order_by))
             return [
                 self._window_expression(
                     self._function("row_number"),
                     (*inputs.partition_by, expr),
                     inputs.order_by,
-                    descending=[True] * len(inputs.order_by),
-                    nulls_last=[True] * len(inputs.order_by),
+                    descending=flags,
+                    nulls_last=flags,
                 )
                 == self._lit(1)
                 for expr in self(df)
